summaryrefslogtreecommitdiffstats
path: root/src/message.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/message.c')
-rw-r--r--src/message.c30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/message.c b/src/message.c
index b5b00f33fe..005a48b1cf 100644
--- a/src/message.c
+++ b/src/message.c
@@ -1179,7 +1179,7 @@ wait_return(int redraw)
// just changed.
screenalloc(FALSE);
- State = HITRETURN;
+ State = MODE_HITRETURN;
setmouse();
#ifdef USE_ON_FLY_SCROLL
dont_scroll = TRUE; // disallow scrolling here
@@ -1351,7 +1351,7 @@ wait_return(int redraw)
(Rows - cmdline_row - 1) * Columns + sc_col)
VIM_CLEAR(keep_msg); // don't redisplay message, it's too long
- if (tmpState == SETWSIZE) // got resize event while in vgetc()
+ if (tmpState == MODE_SETWSIZE) // got resize event while in vgetc()
{
starttermcap(); // start termcap before redrawing
shell_resized();
@@ -1408,7 +1408,7 @@ set_keep_msg(char_u *s, int attr)
set_keep_msg_from_hist(void)
{
if (keep_msg == NULL && last_msg_hist != NULL && msg_scrolled == 0
- && (State & NORMAL))
+ && (State & MODE_NORMAL))
set_keep_msg(last_msg_hist->msg, last_msg_hist->attr);
}
#endif
@@ -2284,7 +2284,7 @@ msg_puts_display(
*/
if (lines_left > 0)
--lines_left;
- if (p_more && lines_left == 0 && State != HITRETURN
+ if (p_more && lines_left == 0 && State != MODE_HITRETURN
&& !msg_no_more && !exmode_active)
{
#ifdef FEAT_CON_DIALOG
@@ -2847,7 +2847,7 @@ do_more_prompt(int typed_char)
// We get called recursively when a timer callback outputs a message. In
// that case don't show another prompt. Also when at the hit-Enter prompt
// and nothing was typed.
- if (entered || (State == HITRETURN && typed_char == 0))
+ if (entered || (State == MODE_HITRETURN && typed_char == 0))
return FALSE;
entered = TRUE;
@@ -2860,7 +2860,7 @@ do_more_prompt(int typed_char)
mp_last = msg_sb_start(mp_last->sb_prev);
}
- State = ASKMORE;
+ State = MODE_ASKMORE;
setmouse();
if (typed_char == NUL)
msg_moremsg(FALSE);
@@ -2880,7 +2880,7 @@ do_more_prompt(int typed_char)
#if defined(FEAT_MENU) && defined(FEAT_GUI)
if (c == K_MENU)
{
- int idx = get_menu_index(current_menu, ASKMORE);
+ int idx = get_menu_index(current_menu, MODE_ASKMORE);
// Used a menu. If it starts with CTRL-Y, it must
// be a "Copy" for the clipboard. Otherwise
@@ -3329,29 +3329,29 @@ msg_moremsg(int full)
}
/*
* Repeat the message for the current mode: ASKMORE, EXTERNCMD, CONFIRM or
* exmode_active.
*/
void
repeat_message(void)
{
- if (State == ASKMORE)
+ if (State == MODE_ASKMORE)
{
msg_moremsg(TRUE); // display --more-- message again
msg_row = Rows - 1;
}
#ifdef FEAT_CON_DIALOG
- else if (State == CONFIRM)
+ else if (State == MODE_CONFIRM)
{
display_confirm_msg(); // display ":confirm" message again
msg_row = Rows - 1;
}
#endif
- else if (State == EXTERNCMD)
+ else if (State == MODE_EXTERNCMD)
{
windgoto(msg_row, msg_col); // put cursor back
}
- else if (State == HITRETURN || State == SETWSIZE)
+ else if (State == MODE_HITRETURN || State == MODE_SETWSIZE)
{
if (msg_row == Rows - 1)
{
@@ -3458,7 +3458,7 @@ msg_end(void)
* we have to redraw the window.
* Do not do this if we are abandoning the file or editing the command line.
*/
- if (!exiting && need_wait_return && !(State & CMDLINE))
+ if (!exiting && need_wait_return && !(State & MODE_CMDLINE))
{
wait_return(FALSE);
return FALSE;
@@ -3811,7 +3811,7 @@ do_dialog(
#endif
oldState = State;
- State = CONFIRM;
+ State = MODE_CONFIRM;
setmouse();
// Ensure raw mode here.
@@ -3329,29 +3329,29 @@ msg_moremsg(int full)
}
/*
- * Repeat the message for the current mode: ASKMORE, EXTERNCMD, CONFIRM or
- * exmode_active.
+ * Repeat the message for the current mode: MODE_ASKMORE, MODE_EXTERNCMD,
+ * MODE_CONFIRM or exmode_active.
*/
void